clear;

%% Calculate chirped pulse waveform

% Define parameters of the chirped pulse.
sampleRate = 100e6;               % Define sample rate of baseband signal (Hz)
pulseWidth = 20e-6;             % Define pulse width (seconds)
pulseRepititionInterval = 50e-6;% Define pulse repetition interval (seconds)
bandWidth =1e6;    % Bandwidth of the pulse (Hz)
IPhase = 0;                     % Initial phase in degrees of IComponent
QPhase = 90;                    % Initial phase in degrees of QComponent

tVector = 0:1/sampleRate:pulseWidth; % Vector to generate ideal pulse
IComponent = chirp(tVector,-bandWidth/2,tVector(end), bandWidth/2,'linear',IPhase);
QComponent = chirp(tVector,-bandWidth/2,tVector(end), bandWidth/2,'linear',QPhase);
IQData = IComponent + 1i*QComponent;

% Normalize amplitude.
scale = max(max(abs(real(IQData))), max(abs(imag(IQData))));
normPulse = IQData / scale;

% Pad the pulse with zeros for the off cycle of the pulse.
offPulse = 0:1/sampleRate:((pulseRepititionInterval-pulseWidth)/2);
chirpedPulse = [offPulse normPulse offPulse];

figure(1); hold on;
plot((1:length(chirpedPulse))/sampleRate, real(chirpedPulse),'b');
plot((1:length(chirpedPulse))/sampleRate, imag(chirpedPulse),'g');
plot((1:length(chirpedPulse))/sampleRate, abs(chirpedPulse),':r','linewidth',2);
grid()
title('One cycle of LFM pulse waveform');
xlabel('Time (s)');
ylabel('Magnitude (V)');
legend('I component','Q component','Envelope');
axis tight; axisLimits = axis; axis([axisLimits(1:2) 1.2*(axisLimits(3:4))]);

isp=chirpedPulse;
save('chirpedPulse_4.mat','isp','-v6');

%% Create and download wv file using R&S MATLAB Toolkit (R&S application note 1GP60)


[err, instrObj] = rs_connect( 'TCPIP','CMA18018-100309' );
if (err ~= 1) 
  disp('*** Exception from rs_connect');
end


[status, answer] = rs_send_query( instrObj, '*IDN?');

if (status ==1) 
  disp(['answer from *IDN? : ' answer]);
else
  disp('*** Exception from rs_send_query');
end

% populate waveform structure
IQInfo.I_data         = imag(chirpedPulse);
IQInfo.Q_data         = real(chirpedPulse);
IQInfo.comment        = 'Waveform created from MATLAB';
IQInfo.clock          = sampleRate;
IQInfo.filename       = 'chirpedPulse_4.wv';

IQInfo.path           = 'D:\Rohde-Schwarz\CMA\Data\waveform\';      % waveform path of CMA180              
 
% Following markers can be linked to CMA180's TRIG OUT connector 
% via master SETUP / Base / Trigger Out Source
IQInfo.markerlist.one = [[0 1];[100 0]];  % not used in CMA180 !
IQInfo.markerlist.two = [[0 1];[2500 0]];  % CMA180: AFRF Gen1: Waveform Marker 2 
IQInfo.markerlist.three = [[0 1];[1000 0]];  % CMA180: AFRF Gen1: Waveform Marker 3 
IQInfo.markerlist.four = [[0 1];[20 0]];  % CMA180: AFRF Gen1: Waveform Marker 4   

% generate waveform (no sending of waveform)
playback   = 1;       % not usable for CMA180
save_local = 1;       % save waveform to PC
[status] = rs_generate_wave (instrObj, IQInfo, playback, save_local); 

if (status ~= 1) 
  disp('*** Exception from rs_generate_wave');
end

    



